% example.m:
% Minimal example showing use of enh_missingdata and enh_nmf.

trainfile = 'train.wav';
testfile = 'test.wav';
enhfile = 'enh.wav';
nmffile = 'enh_nmf.wav';

% train a GMM of clean speech

[trainsig, srate] = wavread(trainfile);
if srate ~= 16000
    trainsig = resample(trainsig, 16000, srate);
end

trainfeats = sig2mel(trainsig);

model = enh_missingdata_train({trainfeats});

% reconstruct cleaned speech based on the model

[testsig, srate] = wavread(testfile);
if srate ~= 16000
    testsig = resample(testsig, 16000, srate);
end

testfeats = sig2mel(testsig);

enhfeats = enh_missingdata(testfeats, model);

enhsig = enh_filter(testsig, testfeats, enhfeats);
if max(abs(enhsig(:))) >= 0.99
    % avoid clipping
    enhsig = 0.99 * enhsig / max(abs(enhsig(:)));
end

wavwrite(enhsig, 16000, ehnfile);

% train a combined clean speech GMM and NMF dictionary

model = enh_nmf_train({trainfeats});

% perform NMF-based feature enhancement

enhfeats = enh_nmf(testfeats, model);
enhsig = enh_filter(testsig, testfeats, enhfeats);
if max(abs(enhsig(:))) >= 0.99
    enhsig = 0.99 * enhsig / max(abs(enhsig(:)));
end
wavwrite(enhsig, 16000, nmffile);
